# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/ocr/v1/ocr.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/ocr/v1/ocr.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n yandex/cloud/ai/ocr/v1/ocr.proto\x12\x16yandex.cloud.ai.ocr.v1\";\n\x07Polygon\x12\x30\n\x08vertices\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.ai.ocr.v1.Vertex\"\x1e\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03\"\xc6\x02\n\x0eTextAnnotation\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12-\n\x06\x62locks\x18\x03 \x03(\x0b\x32\x1d.yandex.cloud.ai.ocr.v1.Block\x12\x30\n\x08\x65ntities\x18\x04 \x03(\x0b\x32\x1e.yandex.cloud.ai.ocr.v1.Entity\x12-\n\x06tables\x18\x05 \x03(\x0b\x32\x1d.yandex.cloud.ai.ocr.v1.Table\x12\x11\n\tfull_text\x18\x06 \x01(\t\x12-\n\x06rotate\x18\x07 \x01(\x0e\x32\x1d.yandex.cloud.ai.ocr.v1.Angle\x12\x10\n\x08markdown\x18\x08 \x01(\t\x12\x31\n\x08pictures\x18\t \x03(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Picture\"$\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xcf\x02\n\x05\x42lock\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12+\n\x05lines\x18\x02 \x03(\x0b\x32\x1c.yandex.cloud.ai.ocr.v1.Line\x12\x41\n\tlanguages\x18\x03 \x03(\x0b\x32..yandex.cloud.ai.ocr.v1.Block.DetectedLanguage\x12;\n\rtext_segments\x18\x04 \x03(\x0b\x32$.yandex.cloud.ai.ocr.v1.TextSegments\x12\x37\n\x0blayout_type\x18\x05 \x01(\x0e\x32\".yandex.cloud.ai.ocr.v1.LayoutType\x1a)\n\x10\x44\x65tectedLanguage\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\"\xe9\x01\n\x04Line\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\x0c\n\x04text\x18\x02 \x01(\t\x12+\n\x05words\x18\x03 \x03(\x0b\x32\x1c.yandex.cloud.ai.ocr.v1.Word\x12;\n\rtext_segments\x18\x04 \x03(\x0b\x32$.yandex.cloud.ai.ocr.v1.TextSegments\x12\x32\n\x0borientation\x18\x05 \x01(\x0e\x32\x1d.yandex.cloud.ai.ocr.v1.Angle\"\x9e\x01\n\x04Word\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x14\n\x0c\x65ntity_index\x18\x03 \x01(\x03\x12;\n\rtext_segments\x18\x04 \x03(\x0b\x32$.yandex.cloud.ai.ocr.v1.TextSegments\"3\n\x0cTextSegments\x12\x13\n\x0bstart_index\x18\x01 \x01(\x03\x12\x0e\n\x06length\x18\x02 \x01(\x03\"\x99\x01\n\x05Table\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\x11\n\trow_count\x18\x02 \x01(\x03\x12\x14\n\x0c\x63olumn_count\x18\x03 \x01(\x03\x12\x30\n\x05\x63\x65lls\x18\x04 \x03(\x0b\x32!.yandex.cloud.ai.ocr.v1.TableCell\"\xdd\x01\n\tTableCell\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\x11\n\trow_index\x18\x02 \x01(\x03\x12\x14\n\x0c\x63olumn_index\x18\x03 \x01(\x03\x12\x13\n\x0b\x63olumn_span\x18\x04 \x01(\x03\x12\x10\n\x08row_span\x18\x05 \x01(\x03\x12\x0c\n\x04text\x18\x06 \x01(\t\x12;\n\rtext_segments\x18\x07 \x03(\x0b\x32$.yandex.cloud.ai.ocr.v1.TextSegments\"O\n\x07Picture\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\r\n\x05score\x18\x02 \x01(\x01*W\n\x05\x41ngle\x12\x15\n\x11\x41NGLE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x41NGLE_0\x10\x01\x12\x0c\n\x08\x41NGLE_90\x10\x02\x12\r\n\tANGLE_180\x10\x03\x12\r\n\tANGLE_270\x10\x04*\xa1\x02\n\nLayoutType\x12\x1b\n\x17LAYOUT_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13LAYOUT_TYPE_UNKNOWN\x10\x01\x12\x14\n\x10LAYOUT_TYPE_TEXT\x10\x02\x12\x16\n\x12LAYOUT_TYPE_HEADER\x10\x03\x12\x1e\n\x1aLAYOUT_TYPE_SECTION_HEADER\x10\x04\x12\x16\n\x12LAYOUT_TYPE_FOOTER\x10\x05\x12\x18\n\x14LAYOUT_TYPE_FOOTNOTE\x10\x06\x12\x17\n\x13LAYOUT_TYPE_PICTURE\x10\x07\x12\x17\n\x13LAYOUT_TYPE_CAPTION\x10\x08\x12\x15\n\x11LAYOUT_TYPE_TITLE\x10\t\x12\x14\n\x10LAYOUT_TYPE_LIST\x10\nB\\\n\x1ayandex.cloud.api.ai.ocr.v1Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/ocr/v1;ocrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.ocr.v1.ocr_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.ai.ocr.v1Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/ocr/v1;ocr'
  _globals['_ANGLE']._serialized_start=1769
  _globals['_ANGLE']._serialized_end=1856
  _globals['_LAYOUTTYPE']._serialized_start=1859
  _globals['_LAYOUTTYPE']._serialized_end=2148
  _globals['_POLYGON']._serialized_start=60
  _globals['_POLYGON']._serialized_end=119
  _globals['_VERTEX']._serialized_start=121
  _globals['_VERTEX']._serialized_end=151
  _globals['_TEXTANNOTATION']._serialized_start=154
  _globals['_TEXTANNOTATION']._serialized_end=480
  _globals['_ENTITY']._serialized_start=482
  _globals['_ENTITY']._serialized_end=518
  _globals['_BLOCK']._serialized_start=521
  _globals['_BLOCK']._serialized_end=856
  _globals['_BLOCK_DETECTEDLANGUAGE']._serialized_start=815
  _globals['_BLOCK_DETECTEDLANGUAGE']._serialized_end=856
  _globals['_LINE']._serialized_start=859
  _globals['_LINE']._serialized_end=1092
  _globals['_WORD']._serialized_start=1095
  _globals['_WORD']._serialized_end=1253
  _globals['_TEXTSEGMENTS']._serialized_start=1255
  _globals['_TEXTSEGMENTS']._serialized_end=1306
  _globals['_TABLE']._serialized_start=1309
  _globals['_TABLE']._serialized_end=1462
  _globals['_TABLECELL']._serialized_start=1465
  _globals['_TABLECELL']._serialized_end=1686
  _globals['_PICTURE']._serialized_start=1688
  _globals['_PICTURE']._serialized_end=1767
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/thresholds.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/thresholds.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/monitoring/v3/thresholds.proto\x12\x1ayandex.cloud.monitoring.v3\"\x85\x02\n\nThresholds\x12:\n\x05items\x18\x01 \x03(\x0b\x32+.yandex.cloud.monitoring.v3.Thresholds.Item\x12\x42\n\tshow_mode\x18\x02 \x01(\x0e\x32/.yandex.cloud.monitoring.v3.Thresholds.ShowMode\x1a\x33\n\x04Item\x12\r\n\x05\x63olor\x18\x01 \x01(\t\x12\x12\n\x05value\x18\x02 \x01(\x01H\x00\x88\x01\x01\x42\x08\n\x06_value\"B\n\x08ShowMode\x12\x19\n\x15SHOW_MODE_UNSPECIFIED\x10\x00\x12\x1b\n\x17SHOW_MODE_CONSTANT_LINE\x10\x01\x42k\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.thresholds_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_THRESHOLDS']._serialized_start=76
  _globals['_THRESHOLDS']._serialized_end=337
  _globals['_THRESHOLDS_ITEM']._serialized_start=218
  _globals['_THRESHOLDS_ITEM']._serialized_end=269
  _globals['_THRESHOLDS_SHOWMODE']._serialized_start=271
  _globals['_THRESHOLDS_SHOWMODE']._serialized_end=337
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.quotamanager.v1.quota_limit_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class QuotaLimitServiceStub:
    """A set of methods for managing quota limits."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.GetQuotaLimitRequest,
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.QuotaLimit,
    ]
    """Returns the specified quota limit."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListQuotaLimitsRequest,
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListQuotaLimitsResponse,
    ]
    """Retrieves the list of quota limits for a given service."""

    ListServices: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListServicesRequest,
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListServicesResponse,
    ]
    """Retrieves the list of services available for quota management."""

class QuotaLimitServiceAsyncStub:
    """A set of methods for managing quota limits."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.GetQuotaLimitRequest,
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.QuotaLimit,
    ]
    """Returns the specified quota limit."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListQuotaLimitsRequest,
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListQuotaLimitsResponse,
    ]
    """Retrieves the list of quota limits for a given service."""

    ListServices: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListServicesRequest,
        yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListServicesResponse,
    ]
    """Retrieves the list of services available for quota management."""

class QuotaLimitServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing quota limits."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.quotamanager.v1.quota_limit_service_pb2.GetQuotaLimitRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.quotamanager.v1.quota_limit_service_pb2.QuotaLimit, collections.abc.Awaitable[yandex.cloud.quotamanager.v1.quota_limit_service_pb2.QuotaLimit]]:
        """Returns the specified quota limit."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListQuotaLimitsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListQuotaLimitsResponse, collections.abc.Awaitable[yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListQuotaLimitsResponse]]:
        """Retrieves the list of quota limits for a given service."""

    @abc.abstractmethod
    def ListServices(
        self,
        request: yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListServicesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListServicesResponse, collections.abc.Awaitable[yandex.cloud.quotamanager.v1.quota_limit_service_pb2.ListServicesResponse]]:
        """Retrieves the list of services available for quota management."""

def add_QuotaLimitServiceServicer_to_server(servicer: QuotaLimitServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.connectionmanager.v1.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RedisAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class UserPasswordAuth(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        USER_FIELD_NUMBER: builtins.int
        PASSWORD_FIELD_NUMBER: builtins.int
        user: builtins.str
        @property
        def password(self) -> yandex.cloud.connectionmanager.v1.common_pb2.Password: ...
        def __init__(
            self,
            *,
            user: builtins.str = ...,
            password: yandex.cloud.connectionmanager.v1.common_pb2.Password | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["password", b"password"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["password", b"password", "user", b"user"]) -> None: ...

    USER_PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def user_password(self) -> global___RedisAuth.UserPasswordAuth: ...
    def __init__(
        self,
        *,
        user_password: global___RedisAuth.UserPasswordAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["security", b"security"]) -> typing.Literal["user_password"] | None: ...

global___RedisAuth = RedisAuth

@typing.final
class RedisCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Host(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Role:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RedisCluster.Host._Role.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ROLE_UNSPECIFIED: RedisCluster.Host._Role.ValueType  # 0
            MASTER: RedisCluster.Host._Role.ValueType  # 1
            REPLICA: RedisCluster.Host._Role.ValueType  # 2

        class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...
        ROLE_UNSPECIFIED: RedisCluster.Host.Role.ValueType  # 0
        MASTER: RedisCluster.Host.Role.ValueType  # 1
        REPLICA: RedisCluster.Host.Role.ValueType  # 2

        class _Health:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RedisCluster.Host._Health.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            HEALTH_UNSPECIFIED: RedisCluster.Host._Health.ValueType  # 0
            ALIVE: RedisCluster.Host._Health.ValueType  # 1
            DEAD: RedisCluster.Host._Health.ValueType  # 2
            DEGRADED: RedisCluster.Host._Health.ValueType  # 3

        class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
        HEALTH_UNSPECIFIED: RedisCluster.Host.Health.ValueType  # 0
        ALIVE: RedisCluster.Host.Health.ValueType  # 1
        DEAD: RedisCluster.Host.Health.ValueType  # 2
        DEGRADED: RedisCluster.Host.Health.ValueType  # 3

        HOST_FIELD_NUMBER: builtins.int
        PORT_FIELD_NUMBER: builtins.int
        ROLE_FIELD_NUMBER: builtins.int
        HEALTH_FIELD_NUMBER: builtins.int
        SHARD_NAME_FIELD_NUMBER: builtins.int
        host: builtins.str
        port: builtins.int
        role: global___RedisCluster.Host.Role.ValueType
        health: global___RedisCluster.Host.Health.ValueType
        shard_name: builtins.str
        def __init__(
            self,
            *,
            host: builtins.str = ...,
            port: builtins.int = ...,
            role: global___RedisCluster.Host.Role.ValueType = ...,
            health: global___RedisCluster.Host.Health.ValueType = ...,
            shard_name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["health", b"health", "host", b"host", "port", b"port", "role", b"role", "shard_name", b"shard_name"]) -> None: ...

    HOSTS_FIELD_NUMBER: builtins.int
    SENTINEL_PORT_FIELD_NUMBER: builtins.int
    TLS_PARAMS_FIELD_NUMBER: builtins.int
    sentinel_port: builtins.int
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RedisCluster.Host]: ...
    @property
    def tls_params(self) -> yandex.cloud.connectionmanager.v1.common_pb2.TLSParams: ...
    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[global___RedisCluster.Host] | None = ...,
        sentinel_port: builtins.int = ...,
        tls_params: yandex.cloud.connectionmanager.v1.common_pb2.TLSParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_params", b"tls_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "sentinel_port", b"sentinel_port", "tls_params", b"tls_params"]) -> None: ...

global___RedisCluster = RedisCluster

@typing.final
class RedisConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    DATABASES_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> global___RedisCluster: ...
    @property
    def auth(self) -> global___RedisAuth: ...
    @property
    def databases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        cluster: global___RedisCluster | None = ...,
        auth: global___RedisAuth | None = ...,
        databases: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster", "databases", b"databases"]) -> None: ...

global___RedisConnection = RedisConnection



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/eventrouter/v1/bus_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/eventrouter/v1/bus_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.serverless.eventrouter.v1 import bus_pb2 as yandex_dot_cloud_dot_serverless_dot_eventrouter_dot_v1_dot_bus__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/serverless/eventrouter/v1/bus_service.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x30yandex/cloud/serverless/eventrouter/v1/bus.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"%\n\rGetBusRequest\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"b\n\x10ListBusesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"h\n\x11ListBusesResponse\x12:\n\x05\x62uses\x18\x01 \x03(\x0b\x32+.yandex.cloud.serverless.eventrouter.v1.Bus\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xbe\x03\n\x10\x43reateBusRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x91\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x44.yandex.cloud.serverless.eventrouter.v1.CreateBusRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x05 \x01(\x08\x12\x17\n\x0flogging_enabled\x18\x06 \x01(\x08\x12G\n\x0blog_options\x18\x07 \x01(\x0b\x32\x32.yandex.cloud.serverless.eventrouter.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x11\x43reateBusMetadata\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\"\xec\x03\n\x10UpdateBusRequest\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x91\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x44.yandex.cloud.serverless.eventrouter.v1.UpdateBusRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x12\x17\n\x0flogging_enabled\x18\x07 \x01(\x08\x12G\n\x0blog_options\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.serverless.eventrouter.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x11UpdateBusMetadata\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"(\n\x10\x44\x65leteBusRequest\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\")\n\x11\x44\x65leteBusMetadata\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8a\x01\n\x18ListBusOperationsRequest\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"k\n\x19ListBusOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xae\r\n\nBusService\x12\x91\x01\n\x03Get\x12\x35.yandex.cloud.serverless.eventrouter.v1.GetBusRequest\x1a+.yandex.cloud.serverless.eventrouter.v1.Bus\"&\x82\xd3\xe4\x93\x02 \x12\x1e/eventrouter/v1/buses/{bus_id}\x12\x9a\x01\n\x04List\x12\x38.yandex.cloud.serverless.eventrouter.v1.ListBusesRequest\x1a\x39.yandex.cloud.serverless.eventrouter.v1.ListBusesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/eventrouter/v1/buses\x12\xa3\x01\n\x06\x43reate\x12\x38.yandex.cloud.serverless.eventrouter.v1.CreateBusRequest\x1a!.yandex.cloud.operation.Operation\"<\xb2\xd2*\x18\n\x11\x43reateBusMetadata\x12\x03\x42us\x82\xd3\xe4\x93\x02\x1a\"\x15/eventrouter/v1/buses:\x01*\x12\xac\x01\n\x06Update\x12\x38.yandex.cloud.serverless.eventrouter.v1.UpdateBusRequest\x1a!.yandex.cloud.operation.Operation\"E\xb2\xd2*\x18\n\x11UpdateBusMetadata\x12\x03\x42us\x82\xd3\xe4\x93\x02#2\x1e/eventrouter/v1/buses/{bus_id}:\x01*\x12\xbb\x01\n\x06\x44\x65lete\x12\x38.yandex.cloud.serverless.eventrouter.v1.DeleteBusRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2**\n\x11\x44\x65leteBusMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02 *\x1e/eventrouter/v1/buses/{bus_id}\x12\xc8\x01\n\x0eListOperations\x12@.yandex.cloud.serverless.eventrouter.v1.ListBusOperationsRequest\x1a\x41.yandex.cloud.serverless.eventrouter.v1.ListBusOperationsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/eventrouter/v1/buses/{bus_id}/operations\x12\xb5\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/eventrouter/v1/buses/{resource_id}:listAccessBindings\x12\xe4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02:\"5/eventrouter/v1/buses/{resource_id}:setAccessBindings:\x01*\x12\xf1\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=28/eventrouter/v1/buses/{resource_id}:updateAccessBindings:\x01*B\x8b\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x05PERBSZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.bus_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\005PERBSZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _globals['_GETBUSREQUEST'].fields_by_name['bus_id']._loaded_options = None
  _globals['_GETBUSREQUEST'].fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTBUSESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTBUSESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEBUSREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEBUSREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEBUSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEBUSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEBUSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEBUSREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATEBUSREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEBUSREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEBUSREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEBUSREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEBUSREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEBUSREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEBUSREQUEST'].fields_by_name['bus_id']._loaded_options = None
  _globals['_UPDATEBUSREQUEST'].fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEBUSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEBUSREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATEBUSREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEBUSREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEBUSREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEBUSREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEBUSMETADATA'].fields_by_name['bus_id']._loaded_options = None
  _globals['_UPDATEBUSMETADATA'].fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEBUSREQUEST'].fields_by_name['bus_id']._loaded_options = None
  _globals['_DELETEBUSREQUEST'].fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEBUSMETADATA'].fields_by_name['bus_id']._loaded_options = None
  _globals['_DELETEBUSMETADATA'].fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTBUSOPERATIONSREQUEST'].fields_by_name['bus_id']._loaded_options = None
  _globals['_LISTBUSOPERATIONSREQUEST'].fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTBUSOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBUSOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTBUSOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBUSOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTBUSOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTBUSOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_BUSSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_BUSSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002 \022\036/eventrouter/v1/buses/{bus_id}'
  _globals['_BUSSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_BUSSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/eventrouter/v1/buses'
  _globals['_BUSSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_BUSSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\030\n\021CreateBusMetadata\022\003Bus\202\323\344\223\002\032\"\025/eventrouter/v1/buses:\001*'
  _globals['_BUSSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_BUSSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\030\n\021UpdateBusMetadata\022\003Bus\202\323\344\223\002#2\036/eventrouter/v1/buses/{bus_id}:\001*'
  _globals['_BUSSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_BUSSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322**\n\021DeleteBusMetadata\022\025google.protobuf.Empty\202\323\344\223\002 *\036/eventrouter/v1/buses/{bus_id}'
  _globals['_BUSSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_BUSSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002+\022)/eventrouter/v1/buses/{bus_id}/operations'
  _globals['_BUSSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_BUSSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0028\0226/eventrouter/v1/buses/{resource_id}:listAccessBindings'
  _globals['_BUSSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_BUSSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002:\"5/eventrouter/v1/buses/{resource_id}:setAccessBindings:\001*'
  _globals['_BUSSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_BUSSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002=28/eventrouter/v1/buses/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETBUSREQUEST']._serialized_start=353
  _globals['_GETBUSREQUEST']._serialized_end=390
  _globals['_LISTBUSESREQUEST']._serialized_start=392
  _globals['_LISTBUSESREQUEST']._serialized_end=490
  _globals['_LISTBUSESRESPONSE']._serialized_start=492
  _globals['_LISTBUSESRESPONSE']._serialized_end=596
  _globals['_CREATEBUSREQUEST']._serialized_start=599
  _globals['_CREATEBUSREQUEST']._serialized_end=1045
  _globals['_CREATEBUSREQUEST_LABELSENTRY']._serialized_start=1000
  _globals['_CREATEBUSREQUEST_LABELSENTRY']._serialized_end=1045
  _globals['_CREATEBUSMETADATA']._serialized_start=1047
  _globals['_CREATEBUSMETADATA']._serialized_end=1101
  _globals['_UPDATEBUSREQUEST']._serialized_start=1104
  _globals['_UPDATEBUSREQUEST']._serialized_end=1596
  _globals['_UPDATEBUSREQUEST_LABELSENTRY']._serialized_start=1000
  _globals['_UPDATEBUSREQUEST_LABELSENTRY']._serialized_end=1045
  _globals['_UPDATEBUSMETADATA']._serialized_start=1598
  _globals['_UPDATEBUSMETADATA']._serialized_end=1639
  _globals['_DELETEBUSREQUEST']._serialized_start=1641
  _globals['_DELETEBUSREQUEST']._serialized_end=1681
  _globals['_DELETEBUSMETADATA']._serialized_start=1683
  _globals['_DELETEBUSMETADATA']._serialized_end=1724
  _globals['_LISTBUSOPERATIONSREQUEST']._serialized_start=1727
  _globals['_LISTBUSOPERATIONSREQUEST']._serialized_end=1865
  _globals['_LISTBUSOPERATIONSRESPONSE']._serialized_start=1867
  _globals['_LISTBUSOPERATIONSRESPONSE']._serialized_end=1974
  _globals['_BUSSERVICE']._serialized_start=1977
  _globals['_BUSSERVICE']._serialized_end=3687
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/foundation_models/v1/text_classification/text_classification_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/foundation_models/v1/text_classification/text_classification_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.ai.foundation_models.v1.text_classification import text_classification_pb2 as yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZyandex/cloud/ai/foundation_models/v1/text_classification/text_classification_service.proto\x12\x38yandex.cloud.ai.foundation_models.v1.text_classification\x1a\x1cgoogle/api/annotations.proto\x1aRyandex/cloud/ai/foundation_models/v1/text_classification/text_classification.proto\"<\n\x19TextClassificationRequest\x12\x11\n\tmodel_uri\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xad\x01\n\x1aTextClassificationResponse\x12\x62\n\x0bpredictions\x18\x01 \x03(\x0b\x32M.yandex.cloud.ai.foundation_models.v1.text_classification.ClassificationLabel\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\x14\n\x0cinput_tokens\x18\x03 \x01(\x03\"\xce\x01\n FewShotTextClassificationRequest\x12\x11\n\tmodel_uri\x18\x01 \x01(\t\x12\x18\n\x10task_description\x18\x02 \x01(\t\x12\x0e\n\x06labels\x18\x03 \x03(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12_\n\x07samples\x18\x05 \x03(\x0b\x32N.yandex.cloud.ai.foundation_models.v1.text_classification.ClassificationSample\"\xb4\x01\n!FewShotTextClassificationResponse\x12\x62\n\x0bpredictions\x18\x01 \x03(\x0b\x32M.yandex.cloud.ai.foundation_models.v1.text_classification.ClassificationLabel\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\x14\n\x0cinput_tokens\x18\x03 \x01(\x03\x32\x8f\x04\n\x19TextClassificationService\x12\xe9\x01\n\x08\x43lassify\x12S.yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationRequest\x1aT.yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationResponse\"2\x82\xd3\xe4\x93\x02,\"\'/foundationModels/v1/textClassification:\x01*\x12\x85\x02\n\x0f\x46\x65wShotClassify\x12Z.yandex.cloud.ai.foundation_models.v1.text_classification.FewShotTextClassificationRequest\x1a[.yandex.cloud.ai.foundation_models.v1.text_classification.FewShotTextClassificationResponse\"9\x82\xd3\xe4\x93\x02\x33\"./foundationModels/v1/fewShotTextClassification:\x01*B\xb0\x01\n<yandex.cloud.api.ai.foundation_models.v1.text_classificationZpgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_classification;text_classificationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n<yandex.cloud.api.ai.foundation_models.v1.text_classificationZpgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_classification;text_classification'
  _globals['_TEXTCLASSIFICATIONSERVICE'].methods_by_name['Classify']._loaded_options = None
  _globals['_TEXTCLASSIFICATIONSERVICE'].methods_by_name['Classify']._serialized_options = b'\202\323\344\223\002,\"\'/foundationModels/v1/textClassification:\001*'
  _globals['_TEXTCLASSIFICATIONSERVICE'].methods_by_name['FewShotClassify']._loaded_options = None
  _globals['_TEXTCLASSIFICATIONSERVICE'].methods_by_name['FewShotClassify']._serialized_options = b'\202\323\344\223\0023\"./foundationModels/v1/fewShotTextClassification:\001*'
  _globals['_TEXTCLASSIFICATIONREQUEST']._serialized_start=266
  _globals['_TEXTCLASSIFICATIONREQUEST']._serialized_end=326
  _globals['_TEXTCLASSIFICATIONRESPONSE']._serialized_start=329
  _globals['_TEXTCLASSIFICATIONRESPONSE']._serialized_end=502
  _globals['_FEWSHOTTEXTCLASSIFICATIONREQUEST']._serialized_start=505
  _globals['_FEWSHOTTEXTCLASSIFICATIONREQUEST']._serialized_end=711
  _globals['_FEWSHOTTEXTCLASSIFICATIONRESPONSE']._serialized_start=714
  _globals['_FEWSHOTTEXTCLASSIFICATIONRESPONSE']._serialized_end=894
  _globals['_TEXTCLASSIFICATIONSERVICE']._serialized_start=897
  _globals['_TEXTCLASSIFICATIONSERVICE']._serialized_end=1424
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/lockbox/v1/payload.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/lockbox/v1/payload.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/lockbox/v1/payload.proto\x12\x17yandex.cloud.lockbox.v1\"\xa3\x01\n\x07Payload\x12\x12\n\nversion_id\x18\x01 \x01(\t\x12\x37\n\x07\x65ntries\x18\x02 \x03(\x0b\x32&.yandex.cloud.lockbox.v1.Payload.Entry\x1aK\n\x05\x45ntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x14\n\ntext_value\x18\x02 \x01(\tH\x00\x12\x16\n\x0c\x62inary_value\x18\x03 \x01(\x0cH\x00\x42\x07\n\x05valueBb\n\x1byandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockboxb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.lockbox.v1.payload_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockbox'
  _globals['_PAYLOAD']._serialized_start=67
  _globals['_PAYLOAD']._serialized_end=230
  _globals['_PAYLOAD_ENTRY']._serialized_start=155
  _globals['_PAYLOAD_ENTRY']._serialized_end=230
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.video.v1.stream_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetStreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream to retrieve."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___GetStreamRequest = GetStreamRequest

@typing.final
class ListStreamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the streams to list."""
    page_size: builtins.int
    """The maximum number of streams to return per page."""
    page_token: builtins.str
    """Page token for retrieving the next page of results.
    This token is obtained from the next_page_token field in the previous ListStreamsResponse.
    """
    order_by: builtins.str
    """Specifies the ordering of results.
    Format is "<field> <order>" (e.g., "startTime desc").
    Default: "id asc".
    Supported fields: ["id", "title", "startTime", "finishTime", "createdAt", "updatedAt"].
    Both snake_case and camelCase field names are supported.
    """
    filter: builtins.str
    """Filter expression to narrow down the list of returned streams.
    Expressions consist of terms connected by logical operators.
    Values containing spaces or quotes must be enclosed in quotes (`'` or `"`)
    with inner quotes being backslash-escaped.

    Supported logical operators: ["AND", "OR"].
    Supported comparison operators: ["=", "!=", ":"] where ":" enables substring matching.
    Parentheses can be used to group logical expressions.

    Example: `title:'live' AND (status='READY' OR status='ONAIR')`

    Filterable fields: ["id", "title", "lineId", "status"].
    Both snake_case and camelCase field names are supported.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListStreamsRequest = ListStreamsRequest

@typing.final
class ListStreamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAMS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for retrieving the next page of results.
    Empty if there are no more results available.
    """
    @property
    def streams(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.stream_pb2.Stream]:
        """List of streams matching the request criteria.
        May be empty if no streams match the criteria or if the channel has no streams.
        """

    def __init__(
        self,
        *,
        streams: collections.abc.Iterable[yandex.cloud.video.v1.stream_pb2.Stream] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "streams", b"streams"]) -> None: ...

global___ListStreamsResponse = ListStreamsResponse

@typing.final
class BatchGetStreamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    STREAM_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the streams to retrieve."""
    @property
    def stream_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of stream IDs to retrieve."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        stream_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "stream_ids", b"stream_ids"]) -> None: ...

global___BatchGetStreamsRequest = BatchGetStreamsRequest

@typing.final
class BatchGetStreamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAMS_FIELD_NUMBER: builtins.int
    @property
    def streams(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.stream_pb2.Stream]:
        """List of streams matching the requested IDs."""

    def __init__(
        self,
        *,
        streams: collections.abc.Iterable[yandex.cloud.video.v1.stream_pb2.Stream] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["streams", b"streams"]) -> None: ...

global___BatchGetStreamsResponse = BatchGetStreamsResponse

@typing.final
class CreateStreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    AUTO_PUBLISH_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ON_DEMAND_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel where the stream will be created."""
    line_id: builtins.str
    """ID of the stream line to which this stream will be linked.
    Stream lines define the technical configuration for streaming.
    """
    title: builtins.str
    """Title of the stream to be displayed in interfaces and players."""
    description: builtins.str
    """Detailed description of the stream content and context.
    Optional field that can provide additional information about the stream.
    """
    thumbnail_id: builtins.str
    """ID of the thumbnail image to be used for the stream."""
    @property
    def auto_publish(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls whether the stream is automatically published when ready.
        When set to true, the stream's status will automatically change from
        READY to ONAIR when the streaming infrastructure is prepared,
        making it available for viewing without manual intervention.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom user-defined labels as `key:value` pairs.
        Maximum 64 labels per stream.
        Keys must be lowercase alphanumeric strings with optional hyphens/underscores.
        Values can contain alphanumeric characters and various symbols.
        """

    @property
    def on_demand(self) -> global___OnDemandParams:
        """On-demand stream that starts immediately when a video signal appears.
        This type of stream has no predetermined start or end time.
        """

    @property
    def schedule(self) -> global___ScheduleParams:
        """Scheduled stream that starts and finishes at specified time.
        This type of stream has predetermined start and end time.
        """

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        line_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        auto_publish: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        on_demand: global___OnDemandParams | None = ...,
        schedule: global___ScheduleParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_publish", b"auto_publish", "on_demand", b"on_demand", "schedule", b"schedule", "stream_type", b"stream_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_publish", b"auto_publish", "channel_id", b"channel_id", "description", b"description", "labels", b"labels", "line_id", b"line_id", "on_demand", b"on_demand", "schedule", b"schedule", "stream_type", b"stream_type", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["stream_type", b"stream_type"]) -> typing.Literal["on_demand", "schedule"] | None: ...

global___CreateStreamRequest = CreateStreamRequest

@typing.final
class OnDemandParams(google.protobuf.message.Message):
    """On-demand streams start automatically when a video signal is detected
    and must be manually stopped when no longer needed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OnDemandParams = OnDemandParams

@typing.final
class ScheduleParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    FINISH_TIME_FIELD_NUMBER: builtins.int
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Scheduled time when the stream should automatically start.
        The streaming infrastructure will be prepared at this time
        and will begin accepting the video signal.
        """

    @property
    def finish_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Scheduled time when the stream should automatically finish.
        The streaming infrastructure will be shut down at this time
        and the stream will be marked as FINISHED.
        """

    def __init__(
        self,
        *,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["finish_time", b"finish_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["finish_time", b"finish_time", "start_time", b"start_time"]) -> None: ...

global___ScheduleParams = ScheduleParams

@typing.final
class CreateStreamMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream being created."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___CreateStreamMetadata = CreateStreamMetadata

@typing.final
class UpdateStreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    STREAM_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    AUTO_PUBLISH_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ON_DEMAND_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    line_id: builtins.str
    """DEPRECATED."""
    title: builtins.str
    """Stream title."""
    description: builtins.str
    """Stream description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields of the stream should be updated.
        Only fields specified in this mask will be modified;
        all other fields will retain their current values.
        This allows for partial updates.
        """

    @property
    def auto_publish(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Automatically publish stream when ready.
        Switches status from READY to ONAIR.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New custom labels for the stream as `key:value` pairs.
        Maximum 64 labels per stream.
        If provided, replaces all existing labels.
        """

    @property
    def on_demand(self) -> global___OnDemandParams:
        """On demand stream.
        It starts immediately when a signal appears.
        """

    @property
    def schedule(self) -> global___ScheduleParams:
        """Scheduled stream.
        It starts and finishes at specified time.
        """

    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        line_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        auto_publish: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        on_demand: global___OnDemandParams | None = ...,
        schedule: global___ScheduleParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_publish", b"auto_publish", "field_mask", b"field_mask", "on_demand", b"on_demand", "schedule", b"schedule", "stream_type", b"stream_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_publish", b"auto_publish", "description", b"description", "field_mask", b"field_mask", "labels", b"labels", "line_id", b"line_id", "on_demand", b"on_demand", "schedule", b"schedule", "stream_id", b"stream_id", "stream_type", b"stream_type", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["stream_type", b"stream_type"]) -> typing.Literal["on_demand", "schedule"] | None: ...

global___UpdateStreamRequest = UpdateStreamRequest

@typing.final
class UpdateStreamMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___UpdateStreamMetadata = UpdateStreamMetadata

@typing.final
class DeleteStreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream to delete."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___DeleteStreamRequest = DeleteStreamRequest

@typing.final
class DeleteStreamMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream.
    This identifier can be used to track the stream deletion operation.
    """
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___DeleteStreamMetadata = DeleteStreamMetadata

@typing.final
class BatchDeleteStreamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    STREAM_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the streams to delete."""
    @property
    def stream_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of stream IDs to delete.
        All streams must exist in the specified channel.
        """

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        stream_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "stream_ids", b"stream_ids"]) -> None: ...

global___BatchDeleteStreamsRequest = BatchDeleteStreamsRequest

@typing.final
class BatchDeleteStreamsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_IDS_FIELD_NUMBER: builtins.int
    @property
    def stream_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of stream IDs being deleted.
        This list can be used to track which streams are included
        in the batch deletion operation.
        """

    def __init__(
        self,
        *,
        stream_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_ids", b"stream_ids"]) -> None: ...

global___BatchDeleteStreamsMetadata = BatchDeleteStreamsMetadata

@typing.final
class PerformStreamActionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    STOP_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream on which to perform the action."""
    @property
    def publish(self) -> global___PublishAction:
        """Publish the stream, changing its status from READY to ONAIR.
        This makes the stream available for watching.
        """

    @property
    def stop(self) -> global___StopAction:
        """Stop the stream, changing its status to FINISHED.
        This terminates the streaming session and releases resources.
        """

    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
        publish: global___PublishAction | None = ...,
        stop: global___StopAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "stop", b"stop"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "stop", b"stop", "stream_id", b"stream_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["publish", "stop"] | None: ...

global___PerformStreamActionRequest = PerformStreamActionRequest

@typing.final
class PublishAction(google.protobuf.message.Message):
    """Parameters for the publish action.
    The action changes the stream's status from READY to ONAIR.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublishAction = PublishAction

@typing.final
class StopAction(google.protobuf.message.Message):
    """Parameters for the stop action.
    The action changes the stream's status to FINISHED.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopAction = StopAction

@typing.final
class PerformStreamActionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream on which the action is being performed.
    This identifier can be used to track the action operation
    and to verify that the action is being applied to the correct stream.
    """
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___PerformStreamActionMetadata = PerformStreamActionMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UsageRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UUID_FIELD_NUMBER: builtins.int
    SKU_ID_FIELD_NUMBER: builtins.int
    QUANTITY_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    uuid: builtins.str
    """Unique identifier of the usage record (UUID format)."""
    sku_id: builtins.str
    """Consumed Marketplace SKU ID, linked to `UsageRecord.product_id`."""
    quantity: builtins.int
    """Quantity of SKU consumed, measured in `sku.usage_unit` units (e.g. bytes)."""
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp in UTC for which the usage is being reported."""

    def __init__(
        self,
        *,
        uuid: builtins.str = ...,
        sku_id: builtins.str = ...,
        quantity: builtins.int = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["quantity", b"quantity", "sku_id", b"sku_id", "timestamp", b"timestamp", "uuid", b"uuid"]) -> None: ...

global___UsageRecord = UsageRecord

@typing.final
class AcceptedUsageRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UUID_FIELD_NUMBER: builtins.int
    uuid: builtins.str
    """Unique identifier of the usage record (UUID format)."""
    def __init__(
        self,
        *,
        uuid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["uuid", b"uuid"]) -> None: ...

global___AcceptedUsageRecord = AcceptedUsageRecord

@typing.final
class RejectedUsageRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Reason:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RejectedUsageRecord._Reason.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REASON_UNSPECIFIED: RejectedUsageRecord._Reason.ValueType  # 0
        DUPLICATE: RejectedUsageRecord._Reason.ValueType  # 1
        EXPIRED: RejectedUsageRecord._Reason.ValueType  # 2
        INVALID_TIMESTAMP: RejectedUsageRecord._Reason.ValueType  # 3
        INVALID_SKU_ID: RejectedUsageRecord._Reason.ValueType  # 4
        INVALID_PRODUCT_ID: RejectedUsageRecord._Reason.ValueType  # 5
        INVALID_QUANTITY: RejectedUsageRecord._Reason.ValueType  # 6
        INVALID_ID: RejectedUsageRecord._Reason.ValueType  # 7

    class Reason(_Reason, metaclass=_ReasonEnumTypeWrapper): ...
    REASON_UNSPECIFIED: RejectedUsageRecord.Reason.ValueType  # 0
    DUPLICATE: RejectedUsageRecord.Reason.ValueType  # 1
    EXPIRED: RejectedUsageRecord.Reason.ValueType  # 2
    INVALID_TIMESTAMP: RejectedUsageRecord.Reason.ValueType  # 3
    INVALID_SKU_ID: RejectedUsageRecord.Reason.ValueType  # 4
    INVALID_PRODUCT_ID: RejectedUsageRecord.Reason.ValueType  # 5
    INVALID_QUANTITY: RejectedUsageRecord.Reason.ValueType  # 6
    INVALID_ID: RejectedUsageRecord.Reason.ValueType  # 7

    UUID_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    uuid: builtins.str
    """Unique identifier of the usage record (UUID format)."""
    reason: global___RejectedUsageRecord.Reason.ValueType
    """The reason of rejection."""
    def __init__(
        self,
        *,
        uuid: builtins.str = ...,
        reason: global___RejectedUsageRecord.Reason.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reason", b"reason", "uuid", b"uuid"]) -> None: ...

global___RejectedUsageRecord = RejectedUsageRecord



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/resource_groups.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/resource_groups.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/mdb/greenplum/v1/resource_groups.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xb9\x03\n\rResourceGroup\x12\x31\n\x04name\x18\x01 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\x12\x33\n\x0fis_user_defined\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x0b\x63oncurrency\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x0e\x63pu_rate_limit\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-100\x12<\n\x0cmemory_limit\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12\x43\n\x13memory_shared_quota\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12\x42\n\x12memory_spill_ratio\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.resource_groups_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_RESOURCEGROUP'].fields_by_name['name']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_RESOURCEGROUP'].fields_by_name['concurrency']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['concurrency']._serialized_options = b'\372\3071\003>=0'
  _globals['_RESOURCEGROUP'].fields_by_name['cpu_rate_limit']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['cpu_rate_limit']._serialized_options = b'\372\3071\0051-100'
  _globals['_RESOURCEGROUP'].fields_by_name['memory_limit']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['memory_limit']._serialized_options = b'\372\3071\0050-100'
  _globals['_RESOURCEGROUP'].fields_by_name['memory_shared_quota']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['memory_shared_quota']._serialized_options = b'\372\3071\0050-100'
  _globals['_RESOURCEGROUP'].fields_by_name['memory_spill_ratio']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['memory_spill_ratio']._serialized_options = b'\372\3071\0050-100'
  _globals['_RESOURCEGROUP']._serialized_start=150
  _globals['_RESOURCEGROUP']._serialized_end=591
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/maintenance_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/maintenance_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.maintenance.v2 import common_pb2 as yandex_dot_cloud_dot_maintenance_dot_v2_dot_common__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/compute/v1/maintenance_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a(yandex/cloud/maintenance/v2/common.proto\x1a&yandex/cloud/operation/operation.proto2\xa0\x04\n\x12MaintenanceService\x12\x95\x01\n\x04List\x12\x34.yandex.cloud.maintenance.v2.ListMaintenancesRequest\x1a\x35.yandex.cloud.maintenance.v2.ListMaintenancesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/compute/v1/maintenances\x12\x96\x01\n\x03Get\x12\x32.yandex.cloud.maintenance.v2.GetMaintenanceRequest\x1a(.yandex.cloud.maintenance.v2.Maintenance\"1\x82\xd3\xe4\x93\x02+\x12)/compute/v1/maintenances/{maintenance_id}\x12\xd8\x01\n\nReschedule\x12\x39.yandex.cloud.maintenance.v2.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*)\x12\'yandex.cloud.maintenance.v2.Maintenance\x82\xd3\xe4\x93\x02\x39\"4/compute/v1/maintenances/{maintenance_id}:reschedule:\x01*B{\n\x1byandex.cloud.api.compute.v1B\x17MaintenanceServiceProtoZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.maintenance_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1B\027MaintenanceServiceProtoZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_MAINTENANCESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_MAINTENANCESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\032\022\030/compute/v1/maintenances'
  _globals['_MAINTENANCESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_MAINTENANCESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/compute/v1/maintenances/{maintenance_id}'
  _globals['_MAINTENANCESERVICE'].methods_by_name['Reschedule']._loaded_options = None
  _globals['_MAINTENANCESERVICE'].methods_by_name['Reschedule']._serialized_options = b'\262\322*)\022\'yandex.cloud.maintenance.v2.Maintenance\202\323\344\223\0029\"4/compute/v1/maintenances/{maintenance_id}:reschedule:\001*'
  _globals['_MAINTENANCESERVICE']._serialized_start=225
  _globals['_MAINTENANCESERVICE']._serialized_end=769
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Connector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Connector._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Connector._Status.ValueType  # 0
        RUNNING: Connector._Status.ValueType  # 1
        STOPPED: Connector._Status.ValueType  # 2
        """disabled by user"""
        RESOURCE_NOT_FOUND: Connector._Status.ValueType  # 3
        """source does not exist"""
        PERMISSION_DENIED: Connector._Status.ValueType  # 4
        """service account does not have read permission on source"""
        SUBJECT_NOT_FOUND: Connector._Status.ValueType  # 5
        """service account not found"""
        DELETING: Connector._Status.ValueType  # 7
        """deletion in progress"""
        CREATING: Connector._Status.ValueType  # 8
        """creation in progress"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Status of the connector."""

    STATUS_UNSPECIFIED: Connector.Status.ValueType  # 0
    RUNNING: Connector.Status.ValueType  # 1
    STOPPED: Connector.Status.ValueType  # 2
    """disabled by user"""
    RESOURCE_NOT_FOUND: Connector.Status.ValueType  # 3
    """source does not exist"""
    PERMISSION_DENIED: Connector.Status.ValueType  # 4
    """service account does not have read permission on source"""
    SUBJECT_NOT_FOUND: Connector.Status.ValueType  # 5
    """service account not found"""
    DELETING: Connector.Status.ValueType  # 7
    """deletion in progress"""
    CREATING: Connector.Status.ValueType  # 8
    """creation in progress"""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    BUS_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the connector."""
    bus_id: builtins.str
    """ID of the bus that the connector belongs to."""
    folder_id: builtins.str
    """ID of the folder that the connector resides in."""
    cloud_id: builtins.str
    """ID of the cloud that the connector resides in."""
    name: builtins.str
    """Name of the connector."""
    description: builtins.str
    """Description of the connector."""
    deletion_protection: builtins.bool
    """Deletion protection."""
    status: global___Connector.Status.ValueType
    """Status of the connector."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def source(self) -> global___Source:
        """Source of the connector."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        bus_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        source: global___Source | None = ...,
        deletion_protection: builtins.bool = ...,
        status: global___Connector.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "cloud_id", b"cloud_id", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "source", b"source", "status", b"status"]) -> None: ...

global___Connector = Connector

@typing.final
class Source(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_STREAM_FIELD_NUMBER: builtins.int
    MESSAGE_QUEUE_FIELD_NUMBER: builtins.int
    TIMER_FIELD_NUMBER: builtins.int
    EVENT_SERVICE_SOURCE_FIELD_NUMBER: builtins.int
    AUDIT_TRAILS_FIELD_NUMBER: builtins.int
    @property
    def data_stream(self) -> global___DataStream: ...
    @property
    def message_queue(self) -> global___MessageQueue: ...
    @property
    def timer(self) -> global___Timer: ...
    @property
    def event_service_source(self) -> global___EventServiceSource: ...
    @property
    def audit_trails(self) -> global___AuditTrails: ...
    def __init__(
        self,
        *,
        data_stream: global___DataStream | None = ...,
        message_queue: global___MessageQueue | None = ...,
        timer: global___Timer | None = ...,
        event_service_source: global___EventServiceSource | None = ...,
        audit_trails: global___AuditTrails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audit_trails", b"audit_trails", "data_stream", b"data_stream", "event_service_source", b"event_service_source", "message_queue", b"message_queue", "source", b"source", "timer", b"timer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audit_trails", b"audit_trails", "data_stream", b"data_stream", "event_service_source", b"event_service_source", "message_queue", b"message_queue", "source", b"source", "timer", b"timer"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["data_stream", "message_queue", "timer", "event_service_source", "audit_trails"] | None: ...

global___Source = Source

@typing.final
class DataStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    STREAM_NAME_FIELD_NUMBER: builtins.int
    CONSUMER_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Stream database. 
    example: /ru-central1/aoegtvhtp8ob********/cc8004q4lbo6********
    """
    stream_name: builtins.str
    """Stream name, absolute or relative."""
    consumer: builtins.str
    """Consumer name."""
    service_account_id: builtins.str
    """Service account which has read permission on the stream."""
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        stream_name: builtins.str = ...,
        consumer: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["consumer", b"consumer", "database", b"database", "service_account_id", b"service_account_id", "stream_name", b"stream_name"]) -> None: ...

global___DataStream = DataStream

@typing.final
class MessageQueue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUEUE_ARN_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    VISIBILITY_TIMEOUT_FIELD_NUMBER: builtins.int
    BATCH_SIZE_FIELD_NUMBER: builtins.int
    POLLING_TIMEOUT_FIELD_NUMBER: builtins.int
    queue_arn: builtins.str
    """Queue ARN.
    Example: yrn:yc:ymq:ru-central1:aoe***:test
    """
    service_account_id: builtins.str
    """Service account which has read access to the queue."""
    batch_size: builtins.int
    """Batch size for polling."""
    @property
    def visibility_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Queue visibility timeout override."""

    @property
    def polling_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Queue polling timeout."""

    def __init__(
        self,
        *,
        queue_arn: builtins.str = ...,
        service_account_id: builtins.str = ...,
        visibility_timeout: google.protobuf.duration_pb2.Duration | None = ...,
        batch_size: builtins.int = ...,
        polling_timeout: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["polling_timeout", b"polling_timeout", "visibility_timeout", b"visibility_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["batch_size", b"batch_size", "polling_timeout", b"polling_timeout", "queue_arn", b"queue_arn", "service_account_id", b"service_account_id", "visibility_timeout", b"visibility_timeout"]) -> None: ...

global___MessageQueue = MessageQueue

@typing.final
class EventServiceSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EventServiceSource = EventServiceSource

@typing.final
class Timer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRON_EXPRESSION_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    cron_expression: builtins.str
    """cron expression, with second precision"""
    time_zone: builtins.str
    """time zone, e.g. Europe/Moscow"""
    payload: builtins.str
    """payload to send to target"""
    def __init__(
        self,
        *,
        cron_expression: builtins.str = ...,
        time_zone: builtins.str = ...,
        payload: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cron_expression", b"cron_expression", "payload", b"payload", "time_zone", b"time_zone"]) -> None: ...

global___Timer = Timer

@typing.final
class AuditTrails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AuditTrails = AuditTrails



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dns/v1/dns_zone_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dns/v1/dns_zone_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.dns.v1 import dns_zone_pb2 as yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/dns/v1/dns_zone_service.proto\x12\x13yandex.cloud.dns.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/dns/v1/dns_zone.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\x86\x01\n#UpdateDnsZonePrivateNetworksRequest\x12\x13\n\x0b\x64ns_zone_id\x18\x01 \x01(\t\x12$\n\x1cprivate_network_id_additions\x18\x02 \x03(\t\x12$\n\x1cprivate_network_id_deletions\x18\x03 \x03(\t\";\n$UpdateDnsZonePrivateNetworksMetadata\x12\x13\n\x0b\x64ns_zone_id\x18\x01 \x01(\t\".\n\x11GetDnsZoneRequest\x12\x19\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x89\x01\n\x13ListDnsZonesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"`\n\x14ListDnsZonesResponse\x12/\n\tdns_zones\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.dns.v1.DnsZone\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa4\x04\n\x14\x43reateDnsZoneRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8a\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.dns.v1.CreateDnsZoneRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x38\n\x04zone\x18\x05 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x19[.]|[a-z0-9][-a-z0-9.]*\\.\x8a\xc8\x31\x05<=255\x12\x42\n\x12private_visibility\x18\x06 \x01(\x0b\x32&.yandex.cloud.dns.v1.PrivateVisibility\x12@\n\x11public_visibility\x18\x07 \x01(\x0b\x32%.yandex.cloud.dns.v1.PublicVisibility\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\",\n\x15\x43reateDnsZoneMetadata\x12\x13\n\x0b\x64ns_zone_id\x18\x01 \x01(\t\"\x97\x04\n\x14UpdateDnsZoneRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8a\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.dns.v1.UpdateDnsZoneRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x42\n\x12private_visibility\x18\x06 \x01(\x0b\x32&.yandex.cloud.dns.v1.PrivateVisibility\x12@\n\x11public_visibility\x18\x07 \x01(\x0b\x32%.yandex.cloud.dns.v1.PublicVisibility\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\",\n\x15UpdateDnsZoneMetadata\x12\x13\n\x0b\x64ns_zone_id\x18\x01 \x01(\t\"3\n\x14\x44\x65leteDnsZoneRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\",\n\x15\x44\x65leteDnsZoneMetadata\x12\x13\n\x0b\x64ns_zone_id\x18\x01 \x01(\t\"r\n\x1aGetDnsZoneRecordSetRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12\x1b\n\x04name\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=255\x12\x1a\n\x04type\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=10\"\x96\x01\n\x1cListDnsZoneRecordSetsRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"m\n\x1dListDnsZoneRecordSetsResponse\x12\x33\n\x0brecord_sets\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb4\x01\n\x17UpdateRecordSetsRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12=\n\tdeletions\x18\x02 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\x12=\n\tadditions\x18\x03 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\"\x1a\n\x18UpdateRecordSetsMetadata\"\xf3\x01\n\x17UpsertRecordSetsRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12=\n\tdeletions\x18\x02 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\x12@\n\x0creplacements\x18\x03 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\x12:\n\x06merges\x18\x04 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\"\x1a\n\x18UpsertRecordSetsMetadata\"u\n\rRecordSetDiff\x12\x31\n\tadditions\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSet\x12\x31\n\tdeletions\x18\x02 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSet\"\x96\x01\n\x1cListDnsZoneOperationsRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"o\n\x1dListDnsZoneOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc8\x13\n\x0e\x44nsZoneService\x12p\n\x03Get\x12&.yandex.cloud.dns.v1.GetDnsZoneRequest\x1a\x1c.yandex.cloud.dns.v1.DnsZone\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/dns/v1/zones/{dns_zone_id}\x12r\n\x04List\x12(.yandex.cloud.dns.v1.ListDnsZonesRequest\x1a).yandex.cloud.dns.v1.ListDnsZonesResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/dns/v1/zones\x12\x94\x01\n\x06\x43reate\x12).yandex.cloud.dns.v1.CreateDnsZoneRequest\x1a!.yandex.cloud.operation.Operation\"<\xb2\xd2* \n\x15\x43reateDnsZoneMetadata\x12\x07\x44nsZone\x82\xd3\xe4\x93\x02\x12\"\r/dns/v1/zones:\x01*\x12\xa2\x01\n\x06Update\x12).yandex.cloud.dns.v1.UpdateDnsZoneRequest\x1a!.yandex.cloud.operation.Operation\"J\xb2\xd2* \n\x15UpdateDnsZoneMetadata\x12\x07\x44nsZone\x82\xd3\xe4\x93\x02 2\x1b/dns/v1/zones/{dns_zone_id}:\x01*\x12\xad\x01\n\x06\x44\x65lete\x12).yandex.cloud.dns.v1.DeleteDnsZoneRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*.\n\x15\x44\x65leteDnsZoneMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1d*\x1b/dns/v1/zones/{dns_zone_id}\x12\x91\x01\n\x0cGetRecordSet\x12/.yandex.cloud.dns.v1.GetDnsZoneRecordSetRequest\x1a\x1e.yandex.cloud.dns.v1.RecordSet\"0\x82\xd3\xe4\x93\x02*\x12(/dns/v1/zones/{dns_zone_id}:getRecordSet\x12\xab\x01\n\x0eListRecordSets\x12\x31.yandex.cloud.dns.v1.ListDnsZoneRecordSetsRequest\x1a\x32.yandex.cloud.dns.v1.ListDnsZoneRecordSetsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/dns/v1/zones/{dns_zone_id}:listRecordSets\x12\xc9\x01\n\x10UpdateRecordSets\x12,.yandex.cloud.dns.v1.UpdateRecordSetsRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*)\n\x18UpdateRecordSetsMetadata\x12\rRecordSetDiff\x82\xd3\xe4\x93\x02\x31\",/dns/v1/zones/{dns_zone_id}:updateRecordSets:\x01*\x12\xc9\x01\n\x10UpsertRecordSets\x12,.yandex.cloud.dns.v1.UpsertRecordSetsRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*)\n\x18UpsertRecordSetsMetadata\x12\rRecordSetDiff\x82\xd3\xe4\x93\x02\x31\",/dns/v1/zones/{dns_zone_id}:upsertRecordSets:\x01*\x12\xa7\x01\n\x0eListOperations\x12\x31.yandex.cloud.dns.v1.ListDnsZoneOperationsRequest\x1a\x32.yandex.cloud.dns.v1.ListDnsZoneOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/dns/v1/zones/{dns_zone_id}/operations\x12\xad\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dns/v1/zones/{resource_id}:listAccessBindings\x12\xdc\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x32\"-/dns/v1/zones/{resource_id}:setAccessBindings:\x01*\x12\xe8\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x35\"0/dns/v1/zones/{resource_id}:updateAccessBindings:\x01*\x12\xe5\x01\n\x15UpdatePrivateNetworks\x12\x38.yandex.cloud.dns.v1.UpdateDnsZonePrivateNetworksRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*/\n$UpdateDnsZonePrivateNetworksMetadata\x12\x07\x44nsZone\x82\xd3\xe4\x93\x02\x36\x32\x31/dns/v1/zones/{dns_zone_id}:updatePrivateNetworks:\x01*BV\n\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dns.v1.dns_zone_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dns'
  _globals['_GETDNSZONEREQUEST'].fields_by_name['dns_zone_id']._loaded_options = None
  _globals['_GETDNSZONEREQUEST'].fields_by_name['dns_zone_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTDNSZONESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDNSZONESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTDNSZONESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDNSZONESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTDNSZONESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDNSZONESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDNSZONESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDNSZONESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEDNSZONEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEDNSZONEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['zone']._loaded_options = None
  _globals['_CREATEDNSZONEREQUEST'].fields_by_name['zone']._serialized_options = b'\350\3071\001\362\3071\031[.]|[a-z0-9][-a-z0-9.]*\\.\212\3101\005<=255'
  _globals['_UPDATEDNSZONEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDNSZONEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDNSZONEREQUEST'].fields_by_name['dns_zone_id']._loaded_options = None
  _globals['_UPDATEDNSZONEREQUEST'].fields_by_name['dns_zone_id']._serialized_options = b'\212\3101\00220'
  _globals['_UPDATEDNSZONEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEDNSZONEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEDNSZONEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEDNSZONEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEDNSZONEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEDNSZONEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_DELETEDNSZONEREQUEST'].fields_by_name['dns_zone_id']._loaded_options = None
  _globals['_DELETEDNSZONEREQUEST'].fields_by_name['dns_zone_id']._serialized_options = b'\212\3101\00220'
  _globals['_GETDNSZONERECORDSETREQUEST'].fields_by_name['dns_zone_id']._loaded_options = None
  _globals['_GETDNSZONERECORDSETREQUEST'].fields_by_name['dns_zone_id']._serialized_options = b'\212\3101\00220'
  _globals['_GETDNSZONERECORDSETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDNSZONERECORDSETREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\005<=255'
  _globals['_GETDNSZONERECORDSETREQUEST'].fields_by_name['type']._loaded_options = None
  _globals['_GETDNSZONERECORDSETREQUEST'].fields_by_name['type']._serialized_options = b'\350\3071\001\212\3101\004<=10'
  _globals['_LISTDNSZONERECORDSETSREQUEST'].fields_by_name['dns_zone_id']._loaded_options = None
  _globals['_LISTDNSZONERECORDSETSREQUEST'].fields_by_name['dns_zone_id']._serialized_options = b'\212\3101\00220'
  _globals['_LISTDNSZONERECORDSETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDNSZONERECORDSETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTDNSZONERECORDSETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDNSZONERECORDSETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDNSZONERECORDSETSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDNSZONERECORDSETSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_UPDATERECORDSETSREQUEST'].fields_by_name['dns_zone_id']._loaded_options = None
  _globals['_UPDATERECORDSETSREQUEST'].fields_by_name['dns_zone_id']._serialized_options = b'\212\3101\00220'
  _globals['_UPDATERECORDSETSREQUEST'].fields_by_name['deletions']._loaded_options = None
  _globals['_UPDATERECORDSETSREQUEST'].fields_by_name['deletions']._serialized_options = b'\202\3101\006<=1000'
  _globals['_UPDATERECORDSETSREQUEST'].fields_by_name['additions']._loaded_options = None
  _globals['_UPDATERECORDSETSREQUEST'].fields_by_name['additions']._serialized_options = b'\202\3101\006<=1000'
  _globals['_UPSERTRECORDSETSREQUEST'].fields_by_name['dns_zone_id']._loaded_options = None
  _globals['_UPSERTRECORDSETSREQUEST'].fields_by_name['dns_zone_id']._serialized_options = b'\212\3101\00220'
  _globals['_UPSERTRECORDSETSREQUEST'].fields_by_name['deletions']._loaded_options = None
  _globals['_UPSERTRECORDSETSREQUEST'].fields_by_name['deletions']._serialized_options = b'\202\3101\006<=1000'
  _globals['_UPSERTRECORDSETSREQUEST'].fields_by_name['replacements']._loaded_options = None
  _globals['_UPSERTRECORDSETSREQUEST'].fields_by_name['replacements']._serialized_options = b'\202\3101\006<=1000'
  _globals['_UPSERTRECORDSETSREQUEST'].fields_by_name['merges']._loaded_options = None
  _globals['_UPSERTRECORDSETSREQUEST'].fields_by_name['merges']._serialized_options = b'\202\3101\006<=1000'
  _globals['_LISTDNSZONEOPERATIONSREQUEST'].fields_by_name['dns_zone_id']._loaded_options = None
  _globals['_LISTDNSZONEOPERATIONSREQUEST'].fields_by_name['dns_zone_id']._serialized_options = b'\212\3101\00220'
  _globals['_LISTDNSZONEOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDNSZONEOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDNSZONEOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDNSZONEOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDNSZONEOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDNSZONEOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_DNSZONESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\035\022\033/dns/v1/zones/{dns_zone_id}'
  _globals['_DNSZONESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\017\022\r/dns/v1/zones'
  _globals['_DNSZONESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateDnsZoneMetadata\022\007DnsZone\202\323\344\223\002\022\"\r/dns/v1/zones:\001*'
  _globals['_DNSZONESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateDnsZoneMetadata\022\007DnsZone\202\323\344\223\002 2\033/dns/v1/zones/{dns_zone_id}:\001*'
  _globals['_DNSZONESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteDnsZoneMetadata\022\025google.protobuf.Empty\202\323\344\223\002\035*\033/dns/v1/zones/{dns_zone_id}'
  _globals['_DNSZONESERVICE'].methods_by_name['GetRecordSet']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['GetRecordSet']._serialized_options = b'\202\323\344\223\002*\022(/dns/v1/zones/{dns_zone_id}:getRecordSet'
  _globals['_DNSZONESERVICE'].methods_by_name['ListRecordSets']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['ListRecordSets']._serialized_options = b'\202\323\344\223\002,\022*/dns/v1/zones/{dns_zone_id}:listRecordSets'
  _globals['_DNSZONESERVICE'].methods_by_name['UpdateRecordSets']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['UpdateRecordSets']._serialized_options = b'\262\322*)\n\030UpdateRecordSetsMetadata\022\rRecordSetDiff\202\323\344\223\0021\",/dns/v1/zones/{dns_zone_id}:updateRecordSets:\001*'
  _globals['_DNSZONESERVICE'].methods_by_name['UpsertRecordSets']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['UpsertRecordSets']._serialized_options = b'\262\322*)\n\030UpsertRecordSetsMetadata\022\rRecordSetDiff\202\323\344\223\0021\",/dns/v1/zones/{dns_zone_id}:upsertRecordSets:\001*'
  _globals['_DNSZONESERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002(\022&/dns/v1/zones/{dns_zone_id}/operations'
  _globals['_DNSZONESERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0020\022./dns/v1/zones/{resource_id}:listAccessBindings'
  _globals['_DNSZONESERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0022\"-/dns/v1/zones/{resource_id}:setAccessBindings:\001*'
  _globals['_DNSZONESERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0025\"0/dns/v1/zones/{resource_id}:updateAccessBindings:\001*'
  _globals['_DNSZONESERVICE'].methods_by_name['UpdatePrivateNetworks']._loaded_options = None
  _globals['_DNSZONESERVICE'].methods_by_name['UpdatePrivateNetworks']._serialized_options = b'\262\322*/\n$UpdateDnsZonePrivateNetworksMetadata\022\007DnsZone\202\323\344\223\002621/dns/v1/zones/{dns_zone_id}:updatePrivateNetworks:\001*'
  _globals['_UPDATEDNSZONEPRIVATENETWORKSREQUEST']._serialized_start=307
  _globals['_UPDATEDNSZONEPRIVATENETWORKSREQUEST']._serialized_end=441
  _globals['_UPDATEDNSZONEPRIVATENETWORKSMETADATA']._serialized_start=443
  _globals['_UPDATEDNSZONEPRIVATENETWORKSMETADATA']._serialized_end=502
  _globals['_GETDNSZONEREQUEST']._serialized_start=504
  _globals['_GETDNSZONEREQUEST']._serialized_end=550
  _globals['_LISTDNSZONESREQUEST']._serialized_start=553
  _globals['_LISTDNSZONESREQUEST']._serialized_end=690
  _globals['_LISTDNSZONESRESPONSE']._serialized_start=692
  _globals['_LISTDNSZONESRESPONSE']._serialized_end=788
  _globals['_CREATEDNSZONEREQUEST']._serialized_start=791
  _globals['_CREATEDNSZONEREQUEST']._serialized_end=1339
  _globals['_CREATEDNSZONEREQUEST_LABELSENTRY']._serialized_start=1294
  _globals['_CREATEDNSZONEREQUEST_LABELSENTRY']._serialized_end=1339
  _globals['_CREATEDNSZONEMETADATA']._serialized_start=1341
  _globals['_CREATEDNSZONEMETADATA']._serialized_end=1385
  _globals['_UPDATEDNSZONEREQUEST']._serialized_start=1388
  _globals['_UPDATEDNSZONEREQUEST']._serialized_end=1923
  _globals['_UPDATEDNSZONEREQUEST_LABELSENTRY']._serialized_start=1294
  _globals['_UPDATEDNSZONEREQUEST_LABELSENTRY']._serialized_end=1339
  _globals['_UPDATEDNSZONEMETADATA']._serialized_start=1925
  _globals['_UPDATEDNSZONEMETADATA']._serialized_end=1969
  _globals['_DELETEDNSZONEREQUEST']._serialized_start=1971
  _globals['_DELETEDNSZONEREQUEST']._serialized_end=2022
  _globals['_DELETEDNSZONEMETADATA']._serialized_start=2024
  _globals['_DELETEDNSZONEMETADATA']._serialized_end=2068
  _globals['_GETDNSZONERECORDSETREQUEST']._serialized_start=2070
  _globals['_GETDNSZONERECORDSETREQUEST']._serialized_end=2184
  _globals['_LISTDNSZONERECORDSETSREQUEST']._serialized_start=2187
  _globals['_LISTDNSZONERECORDSETSREQUEST']._serialized_end=2337
  _globals['_LISTDNSZONERECORDSETSRESPONSE']._serialized_start=2339
  _globals['_LISTDNSZONERECORDSETSRESPONSE']._serialized_end=2448
  _globals['_UPDATERECORDSETSREQUEST']._serialized_start=2451
  _globals['_UPDATERECORDSETSREQUEST']._serialized_end=2631
  _globals['_UPDATERECORDSETSMETADATA']._serialized_start=2633
  _globals['_UPDATERECORDSETSMETADATA']._serialized_end=2659
  _globals['_UPSERTRECORDSETSREQUEST']._serialized_start=2662
  _globals['_UPSERTRECORDSETSREQUEST']._serialized_end=2905
  _globals['_UPSERTRECORDSETSMETADATA']._serialized_start=2907
  _globals['_UPSERTRECORDSETSMETADATA']._serialized_end=2933
  _globals['_RECORDSETDIFF']._serialized_start=2935
  _globals['_RECORDSETDIFF']._serialized_end=3052
  _globals['_LISTDNSZONEOPERATIONSREQUEST']._serialized_start=3055
  _globals['_LISTDNSZONEOPERATIONSREQUEST']._serialized_end=3205
  _globals['_LISTDNSZONEOPERATIONSRESPONSE']._serialized_start=3207
  _globals['_LISTDNSZONEOPERATIONSRESPONSE']._serialized_end=3318
  _globals['_DNSZONESERVICE']._serialized_start=3321
  _globals['_DNSZONESERVICE']._serialized_end=5825
# @@protoc_insertion_point(module_scope)
